import typer
import lovesay.lovesay as lovesay

app = typer.Typer(add_completion=False)

@app.command()
def love(color: str = typer.Argument('catppuccin', help="The name of your preferred color scheme")):
    """
    Supported color schemes: catppuccin, dracula, nord, gruvbox, onedark, tokyonight, rosepine, ayu, palenight, and gogh 
    """
    lovesay.main(color)

def main():
    app()



# ZenithDS
# Lovesay: A script to display a quote from a loved one based on the day of the month
# Last edit Feb 18th, 2022

# Imports to make life easier 
from os.path import expanduser, exists
import os 
import textwrap as tr
from datetime import date
from rich import print
from lovesay.colors import colors

def get_file_path():

    home = expanduser('~')
    filePath = f"{home}/.config/lovesay/quotes"
    
    return filePath

def get_max_width():
    
    cols, rows = os.get_terminal_size()

    if cols // 2 != 0:
        cols -= 1
    
    return cols
    
def generate_quote(file_path):
    
    file_exists = exists(file_path)
   
    if file_exists:
        with open(file_path) as quotesFile:
            quotes = [ quote.rstrip() for quote in quotesFile ]
        
        maxWidth = get_max_width()

        today = date.today()
        todayDate = int(today.strftime("%d"))

        try:
            quotesList = tr.wrap(quotes[(todayDate - 1)], width = (maxWidth - 25))
        except ValueError:
            quotesList = ["", "", "", "", ""]
    else: 
        quotesList = ["", "", "", "", ""]

    return quotesList

def format_quote(quotes_list, colorOne, fg):

    filePath = get_file_path()
    quoteList = ["", "", "", "", ""]

    # A few logic checks right here to decide if the quote should be printed or not
    file_exists = exists(filePath)
    good_width = get_max_width() >= 52
    good_quote_length = len(generate_quote(filePath)) <= 5

    if file_exists and good_width and good_quote_length:
        for q in range(len(quotes_list)):
            quoteList[q] = f"{colorOne} [{fg}]{quotes_list[q]}[/{fg}] {colorOne}"

    return quoteList

def main(color_name):
    
    # Setting up the colors
    color_name = color_name.lower()
    if color_name in colors.keys():
        theme = colors[color_name]
    else:
        theme = colors['catppuccin']

    ONEHEART = f"[{theme['colorOne']}]\u2665[/{theme['colorOne']}]"
    TWOHEART = f"[{theme['colorTwo']}]\u2665[/{theme['colorTwo']}]"
    THREEHEART = f"[{theme['colorThree']}]\u2665[/{theme['colorThree']}]"
    FOURHEART = f"[{theme['colorFour']}]\u2665[/{theme['colorFour']}]"
    FIVEHEART = f"[{theme['colorFive']}]\u2665[/{theme['colorFive']}]"
    SIXHEART = f"[{theme['colorSix']}]\u2665[/{theme['colorSix']}]"

    # Setting up the things needed for the output
    filePath = get_file_path()
    quoteList = format_quote(generate_quote(filePath), ONEHEART, theme['fg'])

    bigHeart = f"   {ONEHEART} {ONEHEART}   {ONEHEART} {ONEHEART}   " \
               f"\n {TWOHEART}     {TWOHEART}     {TWOHEART}      {quoteList[0]}" \
               f"\n {THREEHEART}           {THREEHEART}      {quoteList[1]}" \
               f"\n   {FOURHEART}       {FOURHEART}        {quoteList[2]}" \
               f"\n     {FIVEHEART}   {FIVEHEART}          {quoteList[3]}" \
               f"\n       {SIXHEART}            {quoteList[4]}"


    print(bigHeart)

if __name__ == "__main__":
    main('catppuccin')

# This marks the end of the script

# This was my first attempt at making something nice for myself and perhaps for others,
# I got ticolorOne of only using programming for boring old programming assignments so here we are. 
# I have a long way to go and I guess this is just the starting, I just hope that one day,
# when I look back this code, I'm actually proud of myself instead of being embarrassed. 



colors = {
    "catppuccin" : {
        "colorOne": "#F28FAD",
        "colorTwo": "#DDB6F2",
        "colorThree": "#96CDFB",
        "colorFour": "#ABE9B3",
        "colorFive": "#F8BD96",
        "colorSix": "#FAE3B0",
        "fg": "#D9E0EE",
    },
    "dracula" : {
        "colorOne": "#ff5555",
        "colorTwo": "#bd93f9",
        "colorThree": "#8be9fd",
        "colorFour": "#50fa7b",
        "colorFive": "#ffb86c",
        "colorSix": "#f1fa8c",
        "fg": "#f8f8f2",
    },
    "nord" : {
        "colorOne": "#BF616A",
        "colorTwo": "#B48EAD",
        "colorThree": "#88C0D0",
        "colorFour": "#A3BE8C",
        "colorFive": "#D08770",
        "colorSix": "#EBCB8B",
        "fg": "#ECEFF4",
    },
    "gruvbox" : {
        "colorOne": "#FB4934",
        "colorTwo": "#D3869B",
        "colorThree": "#83A598",
        "colorFour": "#B8BB26",
        "colorFive": "#FE8019",
        "colorSix": "#FABD2F",
        "fg": "#EBDBB2",
    },
    "onedark" : {
        "colorOne": "#E06C75",
        "colorTwo": "#C678DD",
        "colorThree": "#61AFEF",
        "colorFour": "#98C379",
        "colorFive": "#D19A66",
        "colorSix": "#E5C07B",
        "fg": "#ABB2BF",
    },
    "tokyonight" : {
        "colorOne": "#F7768E",
        "colorTwo": "#ad8ee6",
        "colorThree": "#7AA2F7",
        "colorFour": "#9ECE6A",
        "colorFive": "#FF9E64",
        "colorSix": "#E0AF68",
        "fg": "#a9b1d6",
    },
    "rosepine" : {
        "colorOne": "#eb6f92",
        "colorTwo": "#c4a7e7",
        "colorThree": "#9ccfd8",
        "colorFour": "#31748f",
        "colorFive": "#ebbcba",
        "colorSix": "#f6c177",
        "fg": "#e0def4",
    },
    "ayu" : {
        "colorOne": "#ff3333",
        "colorTwo": "#d4bfff",
        "colorThree": "#73d0ff",
        "colorFour": "#bae67e",
        "colorFive": "#ffa759",
        "colorSix": "#ffee99",
        "fg": "#cbccc6",
    },
    "palenight" : {
        "colorOne": "#ff5572",
        "colorTwo": "#c792ea",
        "colorThree": "#60adec",
        "colorFour": "#c3e88d",
        "colorFive": "#f07178",
        "colorSix": "#ffcb6b",
        "fg": "#fffefe",
    },
    "gogh" : {
        "colorOne": "#ff5572",
        "colorTwo": "#f580ff",
        "colorThree": "#75a1ff",
        "colorFour": "#62de84",
        "colorFive": "#f07178",
        "colorSix": "#ffcb6b",
        "fg": "#fffefe",
    }
}



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lovesay']

package_data = \
{'': ['*']}

install_requires = \
['rich>=11.2.0,<12.0.0', 'typer>=0.4.0,<0.5.0']

entry_points = \
{'console_scripts': ['lovesay = lovesay.cli:main']}

setup_kwargs = {
    'name': 'lovesay',
    'version': '0.2.2',
    'description': 'Cowsay, but full of love',
    'long_description': '<h2 align="center"> ━━━━━━  ❖  ━━━━━━ </h2>\n\n<!-- BADGES -->\n<div align="center">\n   <p></p>\n   \n   <img src="https://img.shields.io/github/stars/zenithds/lovesay?color=F8BD96&labelColor=302D41&style=for-the-badge">   \n\n   <img src="https://img.shields.io/github/forks/zenithds/lovesay?color=DDB6F2&labelColor=302D41&style=for-the-badge">   \n\n   <img src="https://img.shields.io/github/repo-size/zenithds/lovesay?color=ABE9B3&labelColor=302D41&style=for-the-badge">\n   \n   <img src="https://badges.pufler.dev/visits/zenithds/lovesay?style=for-the-badge&color=96CDFB&logoColor=white&labelColor=302D41"/>\n   <br>\n</div>\n\n<p/>\n\n---\n\n### ❖ Information \n\n  lovesay is a simple and lightweight python script that displays a quote from a loved one based on the day of the month \n\n  <img src="assets/lovesay.gif" alt="lovesay gif">\n\n---\n\n### ❖ Requirements \n\n- A quotes file stored in `$HOME/.config/lovesay/`\n- Each quote must be on a new line, see the example quotes file in `$HOME/.config/lovesay/quotes`\n- (optional) A partner to write you 31 lines full of love, one for each day of the month\n\n---\n\n### ❖ Installation\n\n> Install from pip\n```sh\n$ pip3 install lovesay\n```\n\n> Install from source\n- First, install [poetry](https://python-poetry.org/)\n```sh\n$ git clone https://github.com/ZenithDS/lovesay.git\n$ cd lovesay\n$ poetry install\n```\n\n### ❖ Usage \n\nlovesay can be used with a variety of different color schemes.\n\n> lovesay uses [catppuccin](https://github.com/catppuccin) as it\'s default color scheme, but a different one can be specified using a positional argument. \n\nFor example:\n```sh\n$ lovesay # uses catppuccin\n```\n  \n```sh\n$ lovesay nord # uses nord \n```\n\nSupported color schemes as of now: \n- [catppuccin](https://github.com/catppuccin)\n- [nord](https://github.com/arcticicestudio/nord)\n- [dracula](https://github.com/dracula/dracula-theme)\n- [gruvbox](https://github.com/morhetz/gruvbox)\n- [onedark](https://github.com/joshdick/onedark.vim)\n\nby default, lovesay checks for the quotes file at `$HOME/.config/lovesay/quotes` if there is nothing there, it will just print out a heart with no quote\n\n---\n\n### ❖ About lovesay\n\nI wrote lovesay because I got tired of seeing neofetch or pfetch every time I opened my terminal. I wanted something more personal. \n\nSeeing words full of love from my partner is a lot better than any other command I could possibly run. It makes my terminal feel cozy, welcoming, and as is the case with most things my partner touches, it makes my terminal feel like home. \n\nI hope that someone else finds a use for this little script as well. Love is a wonderful thing, and we could all use a little bit more of it in our lives (especially arch linux users)\n\n---\n\n### ❖ What\'s New? \n0.2.2 - More Themes and changes to themes config :)\n\n---\n\n<div align="center">\n\n   <img src="https://img.shields.io/static/v1.svg?label=License&message=MIT&color=F5E0DC&labelColor=302D41&style=for-the-badge">\n\n</div>\n',
    'author': 'ZenithDS',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
